==> ejc-labor-impl-3.0.0-20221128.011241-81-sources.jar: com/ejianc/business/labor/bean/SalarySlipEntity.java <==
package com.ejianc.business.labor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工资条
 * 
 * @author generator
 * 
 */
 @TableName("ejc_labor_salary_slip")
public class SalarySlipEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="salary_id")
    private Long salaryId; // 工人工资单主表id
    @TableField(value="salary_detail_id")
    private Long salaryDetailId; // 工人工资单子表id
    @TableField(value="salary_month")
    private Date salaryMonth; // 工资月份
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value = "org_id")
    private Long orgId; // 组织id
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value="worker_id")
    private Long workerId; // 工人id
    @TableField(value="worker_name")
    private String workerName; // 工人
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="supplier_id")
    private Long supplierId; // 加班计量方式
    @TableField(value="supplier_name")
    private String supplierName; // 加班工作量
    @TableField(value="id_card")
    private String idCard; // 身份证号码
    @TableField(value="team_id")
    private String teamId; // 班组id
    @TableField(value="team_name")
    private String teamName; // 班组名称
    @TableField(value="work_type")
    private String workType; // 工种id
    @TableField(value="work_type_name")
    private String workTypeName; // 工种名称
    @TableField(value="sex")
    private Integer sex; // 性別 1:男 2:女
    @TableField(value="phone")
    private String phone; // 手机号
    @TableField(value="bank_card")
    private String bankCard; // 银行卡号
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="wages_type")
    private Integer wagesType; // 工资类型
    @TableField(value="sys_check_num")
    private Integer sysCheckNum; // 系统考勤天数
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="actual_check_num")
    private BigDecimal actualCheckNum; // 实际考勤
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="overtime_mny")
    private BigDecimal overtimeMny; // 加班费
    @TableField(value="deduct_mny")
    private BigDecimal deductMny; // 扣款费用
    @TableField(value="deduct_reason")
    private String deductReason; // 扣款原因
    @TableField(value="should_salary_mny")
    private BigDecimal shouldSalaryMny; // 应发工资:工作量*单价+加班工作量*单价
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source")
    private Integer source; // 来源 1：花名册 2：自制
    @TableField(value="ack_flag")
    private Integer ackFlag; // 确认状态：1：已确认:0：未确认
    @TableField(value="ack_time")
    private Date ackTime; // 确认时间
    @TableField(value="ack_equipment")
    private String ackEquipment; // 确认设备信息


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getSalaryId() {
        return salaryId;
    }

    public void setSalaryId(Long salaryId) {
        this.salaryId = salaryId;
    }
    public Long getSalaryDetailId() {
        return salaryDetailId;
    }

    public void setSalaryDetailId(Long salaryDetailId) {
        this.salaryDetailId = salaryDetailId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Date getSalaryMonth() {
        return salaryMonth;
    }

    public void setSalaryMonth(Date salaryMonth) {
        this.salaryMonth = salaryMonth;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getWorkerId() {
        return workerId;
    }

    public void setWorkerId(Long workerId) {
        this.workerId = workerId;
    }
    public String getWorkerName() {
        return workerName;
    }

    public void setWorkerName(String workerName) {
        this.workerName = workerName;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getTeamId() {
        return teamId;
    }

    public void setTeamId(String teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public String getWorkType() {
        return workType;
    }

    public void setWorkType(String workType) {
        this.workType = workType;
    }
    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getBankCard() {
        return bankCard;
    }

    public void setBankCard(String bankCard) {
        this.bankCard = bankCard;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public Integer getWagesType() {
        return wagesType;
    }

    public void setWagesType(Integer wagesType) {
        this.wagesType = wagesType;
    }
    public Integer getSysCheckNum() {
        return sysCheckNum;
    }

    public void setSysCheckNum(Integer sysCheckNum) {
        this.sysCheckNum = sysCheckNum;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getActualCheckNum() {
        return actualCheckNum;
    }

    public void setActualCheckNum(BigDecimal actualCheckNum) {
        this.actualCheckNum = actualCheckNum;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }
    public BigDecimal getDeductMny() {
        return deductMny;
    }

    public void setDeductMny(BigDecimal deductMny) {
        this.deductMny = deductMny;
    }
    public String getDeductReason() {
        return deductReason;
    }

    public void setDeductReason(String deductReason) {
        this.deductReason = deductReason;
    }
    public BigDecimal getShouldSalaryMny() {
        return shouldSalaryMny;
    }

    public void setShouldSalaryMny(BigDecimal shouldSalaryMny) {
        this.shouldSalaryMny = shouldSalaryMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSource() {
        return source;
    }

    public void setSource(Integer source) {
        this.source = source;
    }
    public Integer getAckFlag() {
        return ackFlag;
    }

    public Date getAckTime() {
        return ackTime;
    }

    public void setAckTime(Date ackTime) {
        this.ackTime = ackTime;
    }

    public void setAckFlag(Integer ackFlag) {
        this.ackFlag = ackFlag;
    }
    public String getAckEquipment() {
        return ackEquipment;
    }

    public void setAckEquipment(String ackEquipment) {
        this.ackEquipment = ackEquipment;
    }
    
}

==> ejc-labor-impl-3.0.0-20221129.083701-91-sources.jar: com/ejianc/business/labor/bean/SalarySlipEntity.java <==
package com.ejianc.business.labor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工资条
 * 
 * @author generator
 * 
 */
 @TableName("ejc_labor_salary_slip")
public class SalarySlipEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="salary_id")
    private Long salaryId; // 工人工资单主表id
    @TableField(value="salary_detail_id")
    private Long salaryDetailId; // 工人工资单子表id
    @TableField(value="salary_month")
    private Date salaryMonth; // 工资月份
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value = "org_id")
    private Long orgId; // 组织id
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value="worker_id")
    private Long workerId; // 工人id
    @TableField(value="worker_name")
    private String workerName; // 工人
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="supplier_id")
    private Long supplierId; // 加班计量方式
    @TableField(value="supplier_name")
    private String supplierName; // 加班工作量
    @TableField(value="id_card")
    private String idCard; // 身份证号码
    @TableField(value="team_id")
    private String teamId; // 班组id
    @TableField(value="team_name")
    private String teamName; // 班组名称
    @TableField(value="work_type")
    private String workType; // 工种id
    @TableField(value="work_type_name")
    private String workTypeName; // 工种名称
    @TableField(value="sex")
    private Integer sex; // 性別 1:男 2:女
    @TableField(value="phone")
    private String phone; // 手机号
    @TableField(value="bank_card")
    private String bankCard; // 银行卡号
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="wages_type")
    private Integer wagesType; // 工资类型
    @TableField(value="sys_check_num")
    private Integer sysCheckNum; // 系统考勤天数
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="actual_check_num")
    private BigDecimal actualCheckNum; // 实际考勤
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="overtime_mny")
    private BigDecimal overtimeMny; // 加班费
    @TableField(value="deduct_mny")
    private BigDecimal deductMny; // 扣款费用
    @TableField(value="deduct_reason")
    private String deductReason; // 扣款原因
    @TableField(value="should_salary_mny")
    private BigDecimal shouldSalaryMny; // 应发工资:工作量*单价+加班工作量*单价
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source")
    private Integer source; // 来源 1：花名册 2：自制
    @TableField(value="ack_flag")
    private Integer ackFlag; // 确认状态：1：已确认:0：未确认
    @TableField(value="ack_time")
    private Date ackTime; // 确认时间
    @TableField(value="logon_people")
    private String logonPeople; // 确认设备信息
    @TableField(value="face_photo_id")
    private Long facePhotoId; // 人脸照片id
    @TableField(value="face_photo")
    private String facePhoto; // 人脸照片地址
    @TableField(value="sign_photo_id")
    private Long signPhotoId; // 签字照片id
    @TableField(value="sign_photo")
    private String signPhoto; // 签字照片地址


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getSalaryId() {
        return salaryId;
    }

    public void setSalaryId(Long salaryId) {
        this.salaryId = salaryId;
    }
    public Long getSalaryDetailId() {
        return salaryDetailId;
    }

    public void setSalaryDetailId(Long salaryDetailId) {
        this.salaryDetailId = salaryDetailId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Date getSalaryMonth() {
        return salaryMonth;
    }

    public void setSalaryMonth(Date salaryMonth) {
        this.salaryMonth = salaryMonth;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getWorkerId() {
        return workerId;
    }

    public void setWorkerId(Long workerId) {
        this.workerId = workerId;
    }
    public String getWorkerName() {
        return workerName;
    }

    public void setWorkerName(String workerName) {
        this.workerName = workerName;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getTeamId() {
        return teamId;
    }

    public void setTeamId(String teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public String getWorkType() {
        return workType;
    }

    public void setWorkType(String workType) {
        this.workType = workType;
    }
    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getBankCard() {
        return bankCard;
    }

    public void setBankCard(String bankCard) {
        this.bankCard = bankCard;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public Integer getWagesType() {
        return wagesType;
    }

    public void setWagesType(Integer wagesType) {
        this.wagesType = wagesType;
    }
    public Integer getSysCheckNum() {
        return sysCheckNum;
    }

    public void setSysCheckNum(Integer sysCheckNum) {
        this.sysCheckNum = sysCheckNum;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getActualCheckNum() {
        return actualCheckNum;
    }

    public void setActualCheckNum(BigDecimal actualCheckNum) {
        this.actualCheckNum = actualCheckNum;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }
    public BigDecimal getDeductMny() {
        return deductMny;
    }

    public void setDeductMny(BigDecimal deductMny) {
        this.deductMny = deductMny;
    }
    public String getDeductReason() {
        return deductReason;
    }

    public void setDeductReason(String deductReason) {
        this.deductReason = deductReason;
    }
    public BigDecimal getShouldSalaryMny() {
        return shouldSalaryMny;
    }

    public void setShouldSalaryMny(BigDecimal shouldSalaryMny) {
        this.shouldSalaryMny = shouldSalaryMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSource() {
        return source;
    }

    public void setSource(Integer source) {
        this.source = source;
    }
    public Integer getAckFlag() {
        return ackFlag;
    }

    public Date getAckTime() {
        return ackTime;
    }

    public void setAckTime(Date ackTime) {
        this.ackTime = ackTime;
    }

    public void setAckFlag(Integer ackFlag) {
        this.ackFlag = ackFlag;
    }

    public String getLogonPeople() {
        return logonPeople;
    }

    public void setLogonPeople(String logonPeople) {
        this.logonPeople = logonPeople;
    }

    public Long getFacePhotoId() {
        return facePhotoId;
    }

    public void setFacePhotoId(Long facePhotoId) {
        this.facePhotoId = facePhotoId;
    }

    public String getFacePhoto() {
        return facePhoto;
    }

    public void setFacePhoto(String facePhoto) {
        this.facePhoto = facePhoto;
    }

    public Long getSignPhotoId() {
        return signPhotoId;
    }

    public void setSignPhotoId(Long signPhotoId) {
        this.signPhotoId = signPhotoId;
    }

    public String getSignPhoto() {
        return signPhoto;
    }

    public void setSignPhoto(String signPhoto) {
        this.signPhoto = signPhoto;
    }
}
